Font

Enum Font 

pub enum Font {
Show 23 variants FontMonotye, Font8x12, Font12x20, Font16x24, Font24x32, Font32x48, Font14x19, Font21x27, Font14x25, FontRoman, FontEpl1, FontEpl2, FontEpl3, FontEpl4, FontEpl5, FontZplA, FontZplB, FontZplD, FontZplE8, FontZplF, FontZplG, FontZplH8, FontZplGs,
}

Variants



FontMonotye

Monotye CG Triumvirate Bold Condensed, font width and height is stretchable



Font8x12

8 x 12 fixed pitch dot font



Font12x20

12 x 20 fixed pitch dot font



Font16x24

16 x 24 fixed pitch dot font



Font24x32

24 x 32 fixed pitch dot font



Font32x48

32 x 48 dot fixed pitch font



Font14x19

14 x 19 dot fixed pitch font OCR-B



Font21x27

21 x 27 dot fixed pitch font OCR-B



Font14x25

14 x25 dot fixed pitch font OCR-A



FontRoman

Monotye CG Triumvirate Bold Condensed, font width and height proportion is fixed



FontEpl1

EPL2 font 1



FontEpl2

EPL2 font 2



FontEpl3

EPL2 font 3



FontEpl4

EPL2 font 4



FontEpl5

EPL2 font 5



FontZplA

ZPL2 font A



FontZplB

ZPL2 font A



FontZplD

ZPL2 font D



FontZplE8

ZPL2 font E8



FontZplF

ZPL2 font F



FontZplG

ZPL2 font G



FontZplH8

ZPL2 font H8



FontZplGs

ZPL2 font GS